pub trait Compactor: Send + Sync {
// Required method
fn compact<'life0, 'async_trait>(
&'life0 self,
messages: Vec<Message>,
) -> Pin<Box<dyn Future<Output = Result<String, String>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Compacts old messages into a summary.
Summaries are injected back into the active window as synthetic system messages, preserving key context while freeing token budget.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".